Overview
========
A distributed, scalable and lightweight environment for deploying and running scrapy spiders/projects with no-hassle on commodity hardware, also it is compatible with scrapyd `/schedule.json` and `/daemonstatus.json`
 , for more info go there: https://github.com/alash3al/scrapy-x

Install
=======

The quick way::

    pip install scrapy-x


